@@ -54,16 +54,17 @@ readAtcMapIntoHashMapAtcCodesAtcNames <-  function (filename, seperator) {
 #' @export
 #'
 #' @examples
-#' utils::data(rawDrugBankCoOcEpSO, package="epos")
+#' utils::data(rawDrugNamesCoOcEpSO, package="epos")
 #' atchashda <-
 #'   readAtcMapIntoHashMapDrugNamesAtcCodes(
 #'   system.file("extdata", "db-atc.map", package = "epos"), "\t")
-#' tepso <- genDictListFromRawFreq(rawDrugBankCoOcEpSO)
+#' tepso <- genDictListFromRawFreq(rawDrugNamesCoOcEpSO)
 #' filterApprovedDrugs(tepso, atchashda)
 filterApprovedDrugs <- function (druglist, atchashda) {
   counter = 0
+  dn <- names(atchashda)
   for (drug in druglist) {
-    if (drug %in% names(atchashda)) {
+    if (drug %in% dn) {
       if (counter == 0) {
         approveddrugs <- drug
       } else {
@@ -86,18 +87,20 @@ filterApprovedDrugs <- function (druglist, atchashda) {
 #' @export
 #'
 #' @examples
-#' utils::data(rawDrugBankCoOcEpSO, package="epos")
+#' utils::data(rawDrugNamesCoOcEpSO, package="epos")
 #' atchashda <-
 #'   readAtcMapIntoHashMapDrugNamesAtcCodes(
 #'   system.file("extdata", "db-atc.map", package = "epos"), "\t")
-#' tepso <- genDictListFromRawFreq(rawDrugBankCoOcEpSO)
+#' tepso <- genDictListFromRawFreq(rawDrugNamesCoOcEpSO)
 #' nepso <- filterNeuroDrugs(tepso, atchashda)
 filterNeuroDrugs <- function (druglist, atchashda) {
   counter = 0
+  dn <- names(atchashda)
   for (drug in druglist) {
-    if (drug %in% names(atchashda)) {
+    if (drug %in% dn) {
       atccode <- atchashda[[drug]]
-      if (startsWith(atccode, "N")) {
+      an <- substring(atccode, 1, 1)
+      if (an == "N") {
         if (counter == 0) {
           neurodrugs <- drug
         } else {
@@ -112,9 +115,9 @@ filterNeuroDrugs <- function (druglist, atchashda) {
   }
 }
 
-#' Read the second level ATC classes from the file drugbankatc-secondlevel.map
+#' Read the second level ATC classes from the file atc-secondlevel.map
 #'
-#' @param filename the file name that is supposed to be drugbankatc-secondlevel.map
+#' @param filename the file name that is supposed to be atc-secondlevel.map
 #' @param seperator the csv file delimiter
 #'
 #' @return atchashsec a hash with second level ATC classes as keys and their names as values
@@ -127,7 +130,7 @@ filterNeuroDrugs <- function (druglist, atchashda) {
 #' @examples
 #' atchashsec <-
 #'   readSecondLevelATC(
-#'   system.file("extdata", "drugbankatc-secondlevel.map", package = "epos"), "\t")
+#'   system.file("extdata", "atc-secondlevel.map", package = "epos"), "\t")
 readSecondLevelATC <- function (filename, seperator) {
   secondatc <- utils::read.csv(file = filename, sep = seperator)
   atcnames <- secondatc[,2]
@@ -146,8 +149,8 @@ readSecondLevelATC <- function (filename, seperator) {
 #' @export
 #'
 #' @examples
-#' utils::data(rawDrugBankCoOcEpSO, package="epos")
-#' genDictListFromRawFreq(rawDrugBankCoOcEpSO)
+#' utils::data(rawDrugNamesCoOcEpSO, package="epos")
+#' genDictListFromRawFreq(rawDrugNamesCoOcEpSO)
 genDictListFromRawFreq <- function (topfreqdictraw) {
   # remove last element from all lists because it is falsely a 1 from previous processing
   la = length(topfreqdictraw)
